%plots selected masses versus temperature
%input:
%From read_rtof output are the following
	%mass is the array with masses
	%counts is the data
	%temp is the temperature
%Enter also a designation string to identify the experiment 
	
function [] = plot_to_eps(mass, counts, temp, designation)

%designation='namestring'
min_mass=10;
max_mass=450;
min_temp=5; %plot only what comes of after that temperature
number_specs=max_mass-min_mass;

%first we make an overview plot of counts over mass
mass_ind = (mass > min_mass & mass < max_mass);
temp_ind = (temp > min_temp);
toplot=sum(counts(:,temp_ind),2);

semilogy (mass(mass_ind), toplot(mass_ind))  ;
		set(gca,'FontSize',10,'LineWidth',1.0)
		set(gca,'XTick',0:10:max_mass)
		set(gca,'XtickLabel', 0 : 10 : max_mass)
		%set(gca,'YTick',:10:max_mass)
		%set(gca,'XtickLabel', 0 : 10 : max_mass)
		xlabel('mass / amu')
		ylabel('log(counts)')
		title(strcat({'counts over mass'}, {' '}, {designation}),'Interpreter','none')
		%axis([min_mass-1 max_mass+1 1 max(sum(counts,2 ))])
		orient landscape
		%set(gca,'ytick',[], 'yticklabel',[])
		%set(gcf, 'PaperPositionMode', 'manual');
		set(gcf, 'PaperUnits', 'inches');
		set(gcf, 'PaperType', 'usletter');
		set(gcf, 'PaperPosition', [0 2 11 5]);
		set(gca,'XGrid','on','YGrid','on','XMinorGrid','on');
		
print ('-depsc', strcat(designation, '_all_counts_over_mass_logscale.eps'));

%semilogy (mass(mass_ind), circshift(toplot(mass_ind),2))  ;
plot (mass(mass_ind), circshift(toplot(mass_ind),2))  ;
%semilogy (mass(mass_ind), toplot(mass_ind))  ;
		set(gca,'FontSize',10,'LineWidth',1.0)
		set(gca,'XTick',0:10:max_mass)
		set(gca,'XtickLabel', 0 : 10 : max_mass)
		%set(gca,'YTick',:10:max_mass)
		%set(gca,'XtickLabel', 0 : 10 : max_mass)
		xlabel('mass / amu')
		ylabel('counts')
		title(strcat({'counts over mass'}, {' '}, {designation}),'Interpreter','none')
		%axis([min_mass-1 max_mass+1 1 max(sum(counts,2 ))])
		orient landscape
		%set(gca,'ytick',[], 'yticklabel',[])
		%set(gcf, 'PaperPositionMode', 'manual');
		set(gcf, 'PaperUnits', 'inches');
		set(gcf, 'PaperType', 'usletter');
		set(gcf, 'PaperPosition', [0 2 11 5]);
		set(gca,'XGrid','on','YGrid','on','XMinorGrid','on');
		
print ('-depsc', strcat(designation, '_all_counts_over_mass.eps'));


%now we make an overview plot of all masses over temperature range
mass_ind = (mass > min_mass & mass < max_mass);
plot (temp, smooth(sum(counts(mass_ind,:),1),7))  ;
		set(gca,'FontSize',20,'LineWidth',1.0)
		xlabel('temperature / K')
		ylabel('all masses over temperature')
		title(strcat({'all masses'}, {' '}, {designation}),'Interpreter','none')
		orient landscape
		set(gca,'ytick',[], 'yticklabel',[])
		%set(gcf, 'PaperPositionMode', 'manual');
		set(gcf, 'PaperUnits', 'inches');
		set(gcf, 'PaperType', 'usletter');
		set(gcf, 'PaperPosition', [0.5 0.5 11 5]);
		set(gca,'XGrid','on','YGrid','off','XMinorGrid','on');
		
print ('-depsc', strcat(designation, '_all_masses_over_temp.eps'));

%now we plot all individual masses over temperature in one extra file:
%! works only with correct time-mass calibration...

peakwidth=0.8; % changes the range around which mass center the passes are integrated. (should be decreased if non-integer m/c is expected)
min_set=10; % sets a minimum threshold to plot 

for kk = min_mass:max_mass;
	mass_ind = (mass > kk - peakwidth/2 & mass < kk + peakwidth/2);
 	plot (temp, smooth(sum(counts(mass_ind,:),1),5),'-b', 'LineWidth',1.25)  ;
		xlabel('Temperature / K');
		ylabel('Arbitrary counts');
		title(strcat({'mass: '},{num2str(kk)},{' amu'}, {' '}, {designation}),'Interpreter','none');
		y_axis_set=max(smooth( sum(counts(mass_ind,:),1) ,5));
		if y_axis_set > min_set ;
			y_max=y_axis_set+0.1*y_axis_set; %set ymax of plot
		else
			y_max=min_set; % if nothing is there, set a ymax anyway to not be confused with noise
		end
		axis([5.5 450 0 y_max]);
		% set(gca,'ytick',[])
		% set(gca,'yticklabel',[])
		set(gcf, 'PaperUnits', 'inches');
		set(gcf, 'PaperType', 'usletter');
		set(gcf, 'PaperPosition', [0.5 0.5 8.5 4.5]);
		set(gca,'FontSize',20,'LineWidth',1.25)
	if kk == min_mass
		print ('-dpsc', strcat(designation, '_single_masses_over_temp.eps'));
	else
		print ('-dpsc', strcat(designation, '_single_masses_over_temp.eps'), '-append');
	end
end



%now we plot a comparison of some desired masses over temperature masses separately:
% colorarray=['k','r','g','b','c','m','y']

% which_masses_to_plot=input('how many masses do you want to compare? Format: "[mass1 mass2 ... massn]". enter "0" for not comparing any masses. max 7 masses!')

% if which_masses_to_plot ~= 0
	% counter=size(which_masses_to_plot,2)
	% mass_string=['']
	% for ll=1:counter
		% mass_string=[mass_string num2str(which_masses_to_plot(ll)) ','];
	% end
	
	% maxima=zeros(1,counter)
	% for gg=1:counter
		% mass_ind = (mass > which_masses_to_plot(gg) - peakwidth/2 & mass < which_masses_to_plot(gg) + peakwidth/2);
		% maxima(gg)=max(smooth( sum(counts(mass_ind,:),1) ,5));
		% plotmax=max(maxima)+0.15*max(maxima);
	% end
	
	% for jj=1:counter
		% mass_ind = (mass > which_masses_to_plot(jj) - peakwidth/2 & mass < which_masses_to_plot(jj) + peakwidth/2);
		% plot (temp, smooth( sum(counts(mass_ind,:),1) ,5), colorarray(jj));
		% hold on
		% xlabel('temperature / K');
		% ylabel('counts');
		% title(strcat({'selected masses: '},{mass_string}));
		% axis([5.5 360 0 plotmax]);
	% set(gca,'ytick',[])
	% set(gca,'yticklabel',[])
		% set(gca,'FontSize',20,'LineWidth',1.25);
	% dummy=strcat('masses ',num2str((selected_mass1_min+selected_mass1_max)/2), 'and ', num2str((selected_mass2_min+selected_mass2_max)/2));
	% end
	%print ('-dpsc', strcat({designation}, {'_selected_masses'},{mass_string},{'.eps'}));
	% hleg1 = legend('m1','m2','m3','m4','m5','m6','m7');
	% set(hleg1,'Location','NorthWest');
	% print ('-dpsc', strcat(designation, '_selected_masses', mass_string, '.eps'));
	% hold off
% end %ends plot-selected-masses loop

end